@@ -254,7 +254,7 @@ file_progress_show (FileOpContext *ctx, long done, long total)
 FileProgressStatus
 file_progress_show_count (FileOpContext *ctx, long done, long total)
 {
-        static gchar count[14]; /* that's a lot of files... */
+        static gchar count[100];
         FileOpContextUI *ui;
 
         g_return_val_if_fail (ctx != NULL, FILE_CONT);
@@ -268,7 +268,7 @@ file_progress_show_count (FileOpContext *ctx, long done, long total)
         if (ui->aborting)
                 return FILE_ABORT;
 
-        snprintf (count, 13, "%d/%d ", done, total);
+        snprintf (count, 100, "%ld/%ld ", done, total);
         gtk_label_set_text (GTK_LABEL (ui->count_label), count);
         while (gtk_events_pending ())
                 gtk_main_iteration ();
@@ -825,6 +825,20 @@ cancel_cb (GtkWidget *widget, gpointer data)
         ui->aborting = TRUE;
 }
 
+/* Handler for the close signal from the GnomeDialog in the file operation
+ * context UI.  We mark the operation as "aborted" and ask GnomeDialog not to
+ * close the window for us.
+ */
+static gboolean
+close_cb (GtkWidget *widget, gpointer data)
+{
+        FileOpContextUI *ui;
+
+        ui = data;
+        ui->aborting = TRUE;
+        return TRUE;
+}
+
 void
 file_op_context_create_ui (FileOpContext *ctx, FileOperation op, int with_eta)
 {
@@ -852,7 +866,12 @@ file_op_context_create_ui (FileOpContext *ctx, FileOperation op, int with_eta)
         gtk_window_set_position (GTK_WINDOW (ui->op_win), GTK_WIN_POS_MOUSE);
 
         gnome_dialog_button_connect (GNOME_DIALOG (ui->op_win), 0,
-                                     GTK_SIGNAL_FUNC (cancel_cb), ui);
+                                     GTK_SIGNAL_FUNC (cancel_cb),
+                                     ui);
+
+        gtk_signal_connect (GTK_OBJECT (ui->op_win), "close",
+                            GTK_SIGNAL_FUNC (close_cb),
+                            ui);
 
         if (op != OP_DELETE) {
                 alignment = gtk_alignment_new (0.0, 0.5, 0, 0);
