@@ -144,7 +144,7 @@
 #include "gsession.h"
 #endif
 
-/* "$Id: main.c,v 1.91 1999/04/06 03:49:43 unammx Exp $" */
+/* "$Id: main.c,v 1.94 1999/04/21 19:18:51 norbert Exp $" */
 
 /* When the modes are active, left_panel, right_panel and tree_panel */
 /* Point to a proper data structure.  You should check with the functions */
@@ -1000,6 +1000,15 @@ _do_panel_cd (WPanel *panel, char *new_dir, enum cd_enum cd_type)
     }
     directory = *new_dir ? new_dir : home_dir;
     
+#ifdef HAVE_GNOME
+    if (is_a_desktop_panel (panel)) {
+	new_panel_at (directory);
+	g_free (olddir);
+	g_free (translated_url);
+	return 0;		/* Don't add to history */
+    }
+#endif
+
     if (mc_chdir (directory) == -1){
 	strcpy (panel->cwd, olddir);
 	g_free (olddir);
@@ -2910,28 +2919,8 @@ compatibility_move_mc_files (void)
 }
 #endif
 
-void
-mc_tree_store_load (void)
-{
-	char *tree_file;
-	
-	tree_file = concat_dir_and_file (home_dir, MC_TREE);
-	tree_store_init ();
-	tree_store_load (tree_file);
-	g_free (tree_file);
-}
-
-void
-mc_tree_store_save (void)
-{
-	char *tree_file;
-
-	tree_file = concat_dir_and_file (home_dir, MC_TREE);
-	tree_store_save (tree_file);
-	g_free (tree_file);
-}
-
-int main (int argc, char *argv [])
+int
+main (int argc, char *argv [])
 {
     /* We had LC_CTYPE before, LC_ALL includs LC_TYPE as well */
     setlocale (LC_ALL, "");
@@ -2980,7 +2969,7 @@ int main (int argc, char *argv [])
 
     handle_args(argc, argv);
 
-    mc_tree_store_load ();
+    tree_store_load ();
 
     session_init ();
     probably_finish_program ();
@@ -3001,6 +2990,10 @@ int main (int argc, char *argv [])
        calls any define_sequence */
     init_key ();
 
+#if defined (HAVE_TEXTMODE_X11_SUPPORT) && !defined (HAVE_X)
+    init_textmode_x11_support ();
+#endif
+
 #ifndef HAVE_GNOME
     handle_args (argc, argv);
 #endif
@@ -3116,7 +3109,7 @@ int main (int argc, char *argv [])
     do_nc ();
 
     /* Save the tree store */
-    mc_tree_store_save ();
+    tree_store_save ();
     
     /* Virtual File System shutdown */
     vfs_shut ();
@@ -3181,6 +3174,11 @@ int main (int argc, char *argv [])
 #ifdef HAVE_MAD
     done_key ();
 #endif
+
+#if defined (HAVE_TEXTMODE_X11_SUPPORT) && !defined (HAVE_X)
+    done_textmode_x11_support ();
+#endif
+
     mad_finalize (__FILE__, __LINE__);
 #ifdef HAVE_X
     xtoolkit_end ();
